@@ -1692,12 +1692,15 @@ bool stageThreeInitialise()
 	// preload model textures for current tileset
 	size_t modelTilesetIdx = static_cast<size_t>(currentMapTileset);
 	modelUpdateTilesetIdx(modelTilesetIdx);
-	enumerateLoadedModels([](const std::string &modelName, iIMDBaseShape &s){
-		for (const iIMDShape *pDisplayShape = s.displayModel(); pDisplayShape != nullptr; pDisplayShape = pDisplayShape->next.get())
-		{
-			pDisplayShape->getTextures();
-		}
-	});
+	if (!headlessGameMode())
+	{
+		enumerateLoadedModels([](const std::string &modelName, iIMDBaseShape &s){
+			for (const iIMDShape *pDisplayShape = s.displayModel(); pDisplayShape != nullptr; pDisplayShape = pDisplayShape->next.get())
+			{
+				pDisplayShape->getTextures();
+			}
+		});
+	}
 	resDoResLoadCallback();		// do callback.
 
 	if (!InitRadar()) 	// After resLoad cause it needs the game palette initialised.
