@@ -1102,7 +1102,7 @@ std::shared_ptr<OptionsBrowserForm> createOptionsBrowser(bool inGame, const std:
 
 	result->addOptionsForm(
 		OptionsBrowserForm::Modes::Interface,
-		[informOnLanguageChangeHandler]() { return makeInterfaceOptionsForm(informOnLanguageChangeHandler); },
+		[inGame, informOnLanguageChangeHandler]() { return makeInterfaceOptionsForm(inGame, informOnLanguageChangeHandler); },
 		N_("Interface")
 	);
 	if (!inGame)
